/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog that display the surface energies calculated from the last erd2003 run
// and allows some calibration slope estimate if the user can provide the surface channel

#include <qhbox.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qmessagebox.h>
#include <qvalidator.h>
#include <fstream.h>

#include "CalibView.h"

CalibView::CalibView(QWidget *parent, QString name )
            : QDialog( parent, name, true )
{
    char s[1000];
    int Z;

    ifstream fi("SURFENER.ERD");
    if(!fi) {
       QMessageBox::warning( this, "Allegria", "Can't open file SURFENER.ERD", QMessageBox::Ok, 0);
       reject();
       return;
    }

    fi.getline(s,1000);
    QBoxLayout *vbox = new QVBoxLayout(this, 2, 2);
    vbox->addWidget(new QLabel( " ", this ));
    vbox->addWidget(new QLabel( "Surface eneries from last ERD run", this ));
    vbox->addWidget(new QLabel( " ", this ));

    QGridLayout *grid = new QGridLayout(vbox,1,5);
    QIntValidator * iv = new QIntValidator(this);

    grid->addWidget(new QLabel(" ",this),0,0);
    grid->addWidget(new QLabel("Z",this),0,1,Qt::AlignHCenter);
    grid->addWidget(new QLabel("E (keV)",this),0,2,Qt::AlignHCenter);
    grid->addWidget(new QLabel("channel",this),0,3,Qt::AlignHCenter);
    grid->addWidget(new QLabel("calib (keV/ch)",this),0,4,Qt::AlignHCenter);

    nAtoms=0;
    for(;;) { //ever
        fi >> s >> Z >> surfEner[nAtoms];
        if(fi.eof()) break;

        grid->expand(5,nAtoms+2);
        grid->addWidget(new QLabel( QString(s),this),nAtoms+1,0,Qt::AlignHCenter);
        grid->addWidget(new QLabel( QString::number(Z),this),nAtoms+1,1,Qt::AlignHCenter);
        grid->addWidget(new QLabel( QString::number(surfEner[nAtoms]),this),nAtoms+1,2,Qt::AlignHCenter);
        channelEdit[nAtoms] = new QLineEdit(QString("0"),this);
        channelEdit[nAtoms]->setValidator(iv);
        channelEdit[nAtoms]->setFixedWidth(60);

        grid->addWidget(channelEdit[nAtoms],nAtoms+1,3,Qt::AlignHCenter);
        calib[nAtoms] = new QLabel("0",this);
        grid->addWidget(calib[nAtoms],nAtoms+1,4,Qt::AlignHCenter);

        connect( channelEdit[nAtoms], SIGNAL( textChanged( const QString & ) ), SLOT(update( const QString &  )) );
        nAtoms++;

        if(nAtoms>50) {
           QMessageBox::warning( this, "Allegria", "To many atoms in SURFENER.ERD", QMessageBox::Ok, 0);
           reject();
           return;
        }
    }
    vbox->addWidget(new QLabel( " ", this ));

    QHBox *tabOk = new QHBox( this );
    vbox->addWidget(tabOk);

    (void) new QLabel( " ", tabOk);

    QPushButton * ok = new QPushButton( "OK", tabOk );
    ok->setDefault(true);
    connect( ok, SIGNAL(clicked()), SLOT(accept()) );

    QPushButton * cancel = new QPushButton( "Cancel", tabOk );
    connect( cancel, SIGNAL(clicked()), SLOT(reject()) );

    setFixedSize(vbox->sizeHint());
}

void CalibView::update( const QString & s)
{
    for(int i=0; i<nAtoms; i++) {
        int ch = channelEdit[i]->text().toInt();
        if(ch==0) calib[i]->setText("0");
        else calib[i]->setText(QString::number(surfEner[i]/ch));
    }
}

