/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef SPECTRUMEXTRACTORWINDOW_H
#define SPECTRUMEXTRACTORWINDOW_H

#include <qmainwindow.h>
#include "../XYQt/FSGraph.h"
#include "../XYQt/PeriodicTable.h"
#include "channelSelector.h"

#define NUMDISPLAY 6  // display 0 (current display) + 5 saved display

class SpectrumExtractorWindow : public QMainWindow
{
	Q_OBJECT
public:
	SpectrumExtractorWindow( QWidget* parent = 0, const char* name = 0, WFlags f = WType_TopLevel );
	~SpectrumExtractorWindow();

private:

	FSDataSet *polygon[MAXELEMENT]; // to store the mass defining polygon

	long divide;    // channel division factor for projection
	long specsize;  // spectrum size for energy graph

	// loaded data are stored here (last column to identify mass)
	short *data[MAXCHAN+1];
	long ndata; // number of events
	long nchan; // nummber of channel

	SXDisplay display[NUMDISPLAY];

	QMenuBar * menu;
	QPopupMenu *recall;
	QPopupMenu *store;

	FSGraph * eventGraph;
	FSGraph * energyGraph;

	QWidget * periodicTableWidget;
	PeriodicTable * periodicTable;

	QString workingDir; // saved working directory name
	QString workingName; // filename of loaded event file without extension

	Atom selectElement(QString s = QString("Periodic Table"));
	bool checkGraphData(FSGraph * g);
	double displayFunction(long i, long param[]);

	bool nparamerror; // used to make a warning appear only once.

public slots:

	bool openEventFile();      // open an Alegria event file
	void about();

	void projection(int type); // project identified data in energy, energy from time, or to show the progression
	void Eprojection();        // used to call projection(type) with type = 1
	void Yprojection();        // project selected data along the Y axis

	bool writeMultiColumn();   // write all spectra in eneryGraph into a single, multicolumn file
	bool writeMultiFile();	   // write each spectrum in eneryGraph into a different file
	bool writeElementEventFile(); // for each selected element, write the corresponding event file

	void changeShape();		   // reshape event graph so spots are horizontal
	void updateData();         // create appropriate dataset from data and channel selection
	void selectChannel();	   // call channel selection dialog
	void recallDisplay(int n);
	void storeDisplay(int n);
	void cancelReshape();
	void definePolygon();
};



#endif // SPECTRUMEXTRACTORWINDOW_H
