/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog for editing datasets plotting properties

#include <qpen.h>
#include <qhbox.h>
#include <qvbox.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qpixmap.h>
#include <qgroupbox.h>
#include <qvalidator.h>
#include <qcolordialog.h>
#include <qtooltip.h>

#include "FSEditDataSet.h"
#include "FSLineEditDouble.h"
#include "xpmSymbol.h"

FSEditDataSet::FSEditDataSet(FSDataSet * d, QWidget *parent, QString name )
            : QDialog( parent, name, true )
{
    QBoxLayout *vbox = new QVBoxLayout(this, 2, 2);

    // legend
    QHBox *tabLegend = new QHBox( this );
    vbox->addWidget(tabLegend);
    (void)new QLabel( "Legend", tabLegend );
    legendEdit = new QLineEdit( d->legend, tabLegend );

    // line and symbol pens
    linePenEdit = new FSPenEdit(d->linePen, "line options", 1, this);
    vbox->addWidget(linePenEdit);

    // symbol and symbol size
    QGroupBox *gb = new QGroupBox( 1, QGroupBox::Vertical, "symbol options", this);
    vbox->addWidget(gb);

    // symbol
    symbolEdit = new QComboBox( false, gb);
    symbolEdit->insertItem( QPixmap(symNone_xpm) );
    symbolEdit->insertItem( QPixmap(symECircle_xpm) );
    symbolEdit->insertItem( QPixmap(symFCircle_xpm) );
    symbolEdit->insertItem( QPixmap(symESquare_xpm) );
    symbolEdit->insertItem( QPixmap(symFSquare_xpm) );
    symbolEdit->insertItem( QPixmap(symETriangle_xpm) );
    symbolEdit->insertItem( QPixmap(symFTriangle_xpm) );
    symbolEdit->insertItem( QPixmap(symERevTriangle_xpm) );
    symbolEdit->insertItem( QPixmap(symFRevTriangle_xpm) );
    symbolEdit->insertItem( QPixmap(symPlus_xpm) );
    symbolEdit->insertItem( QPixmap(symStar_xpm) );
    symbolEdit->insertItem( QPixmap(symDot_xpm) );
    symbolEdit->setCurrentItem(d->getsymbol());

    // color
    _symbolPen = d->symbolPen;
    color = new QPushButton( gb );
    pm.resize(60,20);
    pm.fill(_symbolPen.color());
    color->setPixmap(pm);
    connect( color, SIGNAL(clicked()), SLOT(newSymbolColor()) );

    // symbol size
    symbolSizeEdit = new FSLineEditDouble( QString::number(d->getsymbolSize()), gb );
    symbolSizeEdit->setFixedWidth(60);
    QToolTip::add(symbolSizeEdit,"symbol size can be floating point value");

    QHBox *tabOk = new QHBox( this );
    vbox->addWidget(tabOk);
    //tabOk->setMargin( 5 );
    //tabOk->resize(200,60);
    ok = new QPushButton( "OK", tabOk );
    ok->setDefault(true);
    connect( ok, SIGNAL(clicked()), SLOT(accept()) );

    cancel = new QPushButton( "Cancel", tabOk );
    connect( cancel, SIGNAL(clicked()), SLOT(reject()) );

    setFixedSize(vbox->sizeHint());
}

QString FSEditDataSet::legend( void )
{
    return legendEdit->text();
}

QPen FSEditDataSet::linePen( void )
{
    return linePenEdit->pen();
}

QPen FSEditDataSet::symbolPen( void )
{
    return _symbolPen;
}

int FSEditDataSet::symbol( void )
{
    return symbolEdit->currentItem();
}

double FSEditDataSet::symbolSize( void )
{
    return symbolSizeEdit->text().toDouble();
}

void FSEditDataSet::newSymbolColor( void )
{
    QColor c = QColorDialog::getColor(_symbolPen.color(), this);
    if(c.isValid())
    {
        _symbolPen.setColor(c);
        pm.fill(_symbolPen.color());
        color->setPixmap(pm);
    }
}
