/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog for editing legend properties

#include <qpen.h>
#include <qhbox.h>
#include <qvbox.h>
#include <qgroupbox.h>
#include <qbuttongroup.h>
#include <qpixmap.h>
#include <qfontdialog.h>
#include <qlayout.h>

#include "FSEditLegend.h"

FSEditLegend::FSEditLegend(QPen legPen, QFont legFont, int legPos, QWidget *parent, QString name )
            : QDialog( parent, name, true )
{
    selectedFont  = legFont;

    QBoxLayout *vbox = new QVBoxLayout(this, 2, 2);

    QButtonGroup *bg   = new QButtonGroup( 1, QGroupBox::Horizontal, "Legend Position", this );
    vbox->addWidget(bg);

    legNone    = new QRadioButton( "None", bg );
    legNone->setChecked( legPos==0 );
    legLeft    = new QRadioButton( "Inside Left", bg );
    legLeft->setChecked( legPos==1 );
    legRight   = new QRadioButton( "Inside Right", bg );
    legRight->setChecked( legPos==2 );
    legOutside = new QRadioButton( "Outside Right", bg );
    legOutside->setChecked( legPos==3 );

    // frame line
    linePenEdit = new FSPenEdit(legPen, "Legend frame line", 1, this);
    vbox->addWidget(linePenEdit);

    btFont  = new QPushButton( "Font", this );
    vbox->addWidget(btFont);
    connect( btFont, SIGNAL(clicked()), SLOT(newFont()) );
    colorAndFont = new QCheckBox( "Apply color and font to axes",this);
    vbox->addWidget(colorAndFont );

    QHBox *tabOk = new QHBox( this );
    vbox->addWidget(tabOk );
    tabOk->setMargin( 5 );
    tabOk->resize(200,30);
    ok = new QPushButton( "OK", tabOk );
    ok->setDefault(true);
    connect( ok, SIGNAL(clicked()), SLOT(accept()) );

    cancel = new QPushButton( "Cancel", tabOk );
    connect( cancel, SIGNAL(clicked()), SLOT(reject()) );

    setFixedSize(vbox->sizeHint());
}

void FSEditLegend::newFont()
{
    bool ok;
    QFont f = QFontDialog::getFont(&ok, selectedFont, this);
    if(ok)
        selectedFont = f;
}

QPen FSEditLegend::pen( void )
{
    return linePenEdit->pen();
}

int FSEditLegend::pos( void )
{
    if(legNone->isChecked()) return 0;
    else if(legLeft->isChecked()) return 1;
    else if(legRight->isChecked()) return 2;
    else return 3;
}
