/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog to specify fitting functions and parameters

#include <qvbox.h>
#include <qgroupbox.h>
#include <qlayout.h>
#include <qbuttongroup.h>
#include <qvalidator.h>
#include <qlabel.h>

#include "FSFitDialog.h"

FSFitDialog::FSFitDialog(bool iisMarker, QWidget *parent, QString name )
            : QDialog( parent, name, true )
{
    isMarker = iisMarker;

    QBoxLayout *vbox = new QVBoxLayout(this, 2, 2);

    QButtonGroup *bgtype = new QButtonGroup( 1, QGroupBox::Horizontal, "fit type", this );
    vbox->addWidget(bgtype);
    btBoxCar =     new QRadioButton( "Boxcar average", bgtype );
    btPolynomial = new QRadioButton( "Polynomial", bgtype );
    btSpline =     new QRadioButton( "Spline", bgtype );
    btPolynomial->setChecked(true);
    connect( btBoxCar, SIGNAL(clicked()), SLOT(disablePolate()) );
    connect( btPolynomial, SIGNAL(clicked()), SLOT(enablePolate()) );
    connect( btSpline, SIGNAL(clicked()), SLOT(disablePolate()) );

    QHBox *tabOrder = new QHBox( this );
    vbox->addWidget(tabOrder);
    tabOrder->setMargin( 5 );
    (void)new QLabel( "Order ", tabOrder );
    orderEdit = new QLineEdit( tabOrder );
    QIntValidator * validator = new QIntValidator(0,20, this);
    orderEdit->setValidator(validator);

    cbInterpolate = new QCheckBox("Interpolate between markers", this);
    cbExtrapolate = new QCheckBox("Extrapolate to whole dataset range", this);
    if(!isMarker) disablePolate();
    vbox->addWidget(cbInterpolate);
    vbox->addWidget(cbExtrapolate);

    QHBox *tabOk = new QHBox( this );
    vbox->addWidget(tabOk);
    tabOk->setMargin( 5 );
    ok = new QPushButton( "OK", tabOk );
    ok->setDefault(true);
    connect( ok, SIGNAL(clicked()), SLOT(accept()) );

    cancel = new QPushButton( "Cancel", tabOk );
    connect( cancel, SIGNAL(clicked()), SLOT(reject()) );

    setFixedSize(250,300);

}

//
// return the type of fit:
//   1: boxcar average, 2: polynomial, 3: spline
//
int FSFitDialog::fitType( void )
{
    int op = 2;
    if(btBoxCar->isChecked()) op=1;
    else if(btSpline->isChecked()) op=3;

    return op;
}

int FSFitDialog::order( void )
{
    return orderEdit->text().toInt();
}

void FSFitDialog::disablePolate( void )
{
    cbInterpolate->setEnabled(false);
    cbExtrapolate->setEnabled(false);
}

void FSFitDialog::enablePolate( void )
{
    if(isMarker)
    {
        cbInterpolate->setEnabled(true);
        cbExtrapolate->setEnabled(true);
    }
}

bool FSFitDialog::isExtrapolate( void )
{
    return cbExtrapolate->isChecked();
}

bool FSFitDialog::isInterpolate( void )
{
    return cbInterpolate->isChecked();
}
