/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Dialog to input + - * / operations with constants or other datasets

#include <qvbox.h>

#include "FSOpDialog.h"

FSOpDialog::FSOpDialog(int op, FSDataSet *ffirstDataSet, QWidget *parent, QString name )
            : QDialog( parent, name, true )
{
    firstDataSet = ffirstDataSet;
    if(op<-4 || (op<0 && firstDataSet==NULL) || op>4 || op==0) op=1;

    setFixedSize(220,500);

    QVBox *tab = new QVBox( this );
    tab->setMargin( 5 );
    tab->setSpacing( 5 );
    tab->resize(220,500);

    QButtonGroup *bgtype = new QButtonGroup( 1, QGroupBox::Horizontal, "operation type", tab );
    btConstantOp = new QRadioButton( "with a constant", bgtype );
    connect( btConstantOp, SIGNAL(clicked()), SLOT(constantOp()) );
    btDatasetOp = new QRadioButton( "with a dataset", bgtype );
    if(ffirstDataSet==NULL) btDatasetOp->setEnabled( false );
    connect( btDatasetOp, SIGNAL(clicked()), SLOT(datasetOp()) );

    bg = new QButtonGroup( 1, QGroupBox::Vertical, "operation", tab );
    btPlus   = new QRadioButton( "+", bg );
    btPlus->setChecked( fabs(op)==1 );
    btMinus  = new QRadioButton( "-", bg );
    btMinus->setChecked( fabs(op)==2 );
    btTimes  = new QRadioButton( "*", bg );
    btTimes->setChecked( fabs(op)==3 );
    btDivide = new QRadioButton( "/", bg );
    btDivide->setChecked( fabs(op)==4 );

    gbConstant = new QGroupBox( 1, QGroupBox::Horizontal, "constant", tab);
    constantEdit = new FSLineEditDouble( gbConstant );
    if(op>0)constantEdit->setFocus();
    cbX = new QCheckBox( "operation on X values", gbConstant );
    cbY = new QCheckBox( "operation on Y values", gbConstant );
    cbY->setChecked( true );

    gbDataSet = new QGroupBox( 1, QGroupBox::Horizontal, "data", tab);
    datasets = new QListBox(gbDataSet);
	datasets->setSelectionMode(QListBox::Extended);
    if (firstDataSet)
    {
        FSDataSet* pdataset = firstDataSet;
        while(pdataset)
        {
            datasets->insertItem( pdataset->legend );
            pdataset = pdataset->nextDataSet;
        }
        if(op<0)datasets->setFocus();
    }
    else
        datasets->setEnabled(false);


    QHBox *tabOk = new QHBox( tab );
    tabOk->setMargin( 5 );
    tabOk->resize(200,30);
    ok = new QPushButton( "OK", tabOk );
    ok->setDefault(true);
    connect( ok, SIGNAL(clicked()), SLOT(accept()) );

    cancel = new QPushButton( "Cancel", tabOk );
    connect( cancel, SIGNAL(clicked()), SLOT(reject()) );

    if(op>0)
    {
        btConstantOp->setChecked( true );
        constantOp();
    }
    else
    {
        btDatasetOp->setChecked( true );
        datasetOp();
    }

}

//
// return the operation number: 
//   with constant: 1 for +,  2 for -,  3 for *,  4 for /
//   with dataset: -1 for +, -2 for -, -3 for *, -4 for /
//
int FSOpDialog::operation( void )
{
    int op = 1;
    if(btMinus->isChecked()) op=2;
    else if(btTimes->isChecked()) op=3;
    else if(btDivide->isChecked()) op=4;

    if(btDatasetOp->isChecked()) op = -op;

    return op;
}


// fills the array selectedDataSets[] with pointers to selected datasets 
// the element after the last is set to NULL
void FSOpDialog::selectedDatasets( FSDataSet* listDataSets[] )
{
	int nselected = 0;
	listDataSets[nselected] = NULL;

    if(btDatasetOp->isChecked())
    {
        FSDataSet *ds = firstDataSet;
        for(int i=0; i<int(datasets->count()); i++)
        {
            if(datasets->isSelected(i)) {
				listDataSets[nselected++] = ds;
				listDataSets[nselected] = NULL;
			}
            ds = ds->nextDataSet;
        }
    }
}


double FSOpDialog::constant( void )
{
    return constantEdit->text().toDouble();
}

bool FSOpDialog::onX( void )
{
    return cbX->isChecked();
}

bool FSOpDialog::onY( void )
{
    return cbY->isChecked();
}

void FSOpDialog::constantOp( void )
{
    gbConstant->setEnabled(true);
    constantEdit->setEnabled(true);
    cbX->setEnabled(true);
    cbY->setEnabled(true);

    gbDataSet->setEnabled(false);
    datasets->setEnabled(false);
}

void FSOpDialog::datasetOp( void )
{
    gbConstant->setEnabled(false);
    constantEdit->setEnabled(false);
    cbX->setEnabled(false);
    cbY->setEnabled(false);

    gbDataSet->setEnabled(true);
    datasets->setEnabled(true);
}
