/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

// Widget for setting line properties

#include <qpen.h>
#include <qhbox.h>
#include <qlabel.h>
#include <qgroupbox.h>
#include <qvalidator.h>
#include <qcolordialog.h>
#include <qtooltip.h>
#include <qlayout.h>

#include "FSPenEdit.h"
#include "xpmLineStyle.h"

FSPenEdit::FSPenEdit(QPen p, QString id, int nrow, QWidget *parent, QString name )
            : QWidget( parent, name )
{
    if(nrow<1 || nrow>3) nrow = 3;

    QBoxLayout *vbox = new QVBoxLayout(this, 2, 2);

    QGroupBox *gb = new QGroupBox( nrow, QGroupBox::Vertical, id, this );
    vbox->addWidget(gb);

    //gb->setFixedSize(30+(4-nrow)*60,30+30*nrow);

    if(nrow ==2)
        (void)new QLabel( "Width:", gb );

    // width
    lineWidth = new QLineEdit( QString::number(p.width()), gb );
    lineWidth->setFixedWidth(30);
    QIntValidator * validator = new QIntValidator(0,99, this);
    lineWidth->setValidator(validator);
    if(nrow!=2)
        QToolTip::add(lineWidth,"line width");

    // color
    selectedColor = p.color();
    color = new QPushButton( gb );
    pm.resize(66,20);
    pm.fill(selectedColor);
    color->setPixmap(pm);
    connect( color, SIGNAL(clicked()), SLOT(newColor()) );

    // style
    lineStyle = new QComboBox( false, gb);
    lineStyle->insertItem( QPixmap(lsNone_xpm) );
    lineStyle->insertItem( QPixmap(lsSolid_xpm) );
    lineStyle->insertItem( QPixmap(lsDash_xpm) );
    lineStyle->insertItem( QPixmap(lsDot_xpm) );
    lineStyle->insertItem( QPixmap(lsDashDot_xpm) );
    lineStyle->insertItem( QPixmap(lsDashDotDot_xpm) );
    switch(p.style()) {
    case Qt::SolidLine:
        lineStyle->setCurrentItem(1);
        break;
    case Qt::DashLine:
        lineStyle->setCurrentItem(2);
        break;
    case Qt::DotLine:
        lineStyle->setCurrentItem(3);
        break;
    case Qt::DashDotLine:
        lineStyle->setCurrentItem(4);
        break;
    case Qt::DashDotDotLine:
        lineStyle->setCurrentItem(5);
        break;
    case Qt::NoPen:
    default:
        lineStyle->setCurrentItem(0);
        break;
    }
}

void FSPenEdit::newColor()
{
    QColor c = QColorDialog::getColor(selectedColor, this);
    if(c.isValid())
    {
        selectedColor = c;
        pm.fill(selectedColor);
        color->setPixmap(pm);
    }
}

QPen FSPenEdit::pen( void )
{
    QPen p(selectedColor, lineWidth->text().toInt());
    switch(lineStyle->currentItem()) {
    case 0:
        p.setStyle(Qt::NoPen);
        break;
    case 1:
        p.setStyle(Qt::SolidLine);
        break;
    case 2:
        p.setStyle(Qt::DashLine);
        break;
    case 3:
        p.setStyle(Qt::DotLine);
        break;
    case 4:
        p.setStyle(Qt::DashDotLine);
        break;
    case 5:
        p.setStyle(Qt::DashDotDotLine);
        break;
    }

    return p;
}
