/* This file is part of the Allegria project
   Copyright (C) 2004 Francois Schiettekatte <francois.schiettekatte@umontreal.ca>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef PERIODICTABLE_H
#define PERIODICTABLE_H


#include <qdialog.h>
#include <qpushbutton.h>
#include <qlist.h> 

#define MAXELEMENT 110

class Atom 
{
    public:
        QString     name;
        int         Z;
        double      mass;
        int         nIsotopes;
        double      *isotopes;
    	bool operator ==(const Atom& other) const{return &other == this;}

		Atom() {  name = ""; Z=0; mass = 0.; nIsotopes = 0; isotopes = NULL; }
  
};


class PeriodicTable : public QWidget {

	Q_OBJECT

public:
	PeriodicTable(int w = 300, int h = 200, bool singleSelect = true, bool sshowDummy = false, QWidget *parent=0, QString name=0 );
   ~PeriodicTable();
    Atom selectedElement;
	Atom returnAtom(int atomNum);
	Atom returnAtom(QString atomName);
	void setSelected(int Z, bool sel = true);
	int * multiSelected();
	void paintEvent( QPaintEvent * );

public slots:
	void singleElementSelect();
	void multiElementSelect();

signals:
	void elementSelected();

private:
	void createTableOfElements(int width, int height);
    bool loadAtoms();

    Atom Atoms[MAXELEMENT];  // Atom list
	int nAtoms;
	bool showDummy;  // show a row of dummy atoms Qa, Qb, ... Qr at the bottom

    QPushButton * cb[MAXELEMENT];  // buttons representing elements

	int lastClicked;
	int ZSelected[MAXELEMENT+1];

};

#endif //PERIODICTABLE_H

